From: Mikulas Patocka <mpatocka@redhat.com>

dm-stripe is supposed to ensure that all the space allocated to the
stripes is fully used and that all stripes are the same size.  This
patch fixes the test.  It checks that device length is divisible by the
chunk size and checks that the resulting quotient is divisible by the
number of stripes (which is equivalent to testing if device length is
divisible by chunk_size * stripes).

Previously, the code only tested that the number of sectors in the target
was divisible by each of the chunk size and the number of stripes
separately, which could leave entire stripes unused.

(A setup that genuinely needs some stripes to be shorter than others
can be created by concatenating striped targets.)

Signed-off-by: Mikulas Patocka <mpatocka@redhat.com>
Signed-off-by: Alasdair G Kergon <agk@redhat.com>

---
 Documentation/device-mapper/striped.txt |    3 +--
 drivers/md/dm-stripe.c                  |    1 -
 2 files changed, 1 insertion(+), 3 deletions(-)

Index: linux/Documentation/device-mapper/striped.txt
===================================================================
--- linux.orig/Documentation/device-mapper/striped.txt
+++ linux/Documentation/device-mapper/striped.txt
@@ -16,8 +16,7 @@ Parameters: <num devs> <chunk size> [<de
     <offset>: Starting sector within the device.
 
 One or more underlying devices can be specified. The striped device size must
-be a multiple of the chunk size and a multiple of the number of underlying
-devices.
+be a multiple of the chunk size multiplied by the number of underlying devices.
 
 
 Example scripts
Index: linux/drivers/md/dm-stripe.c
===================================================================
--- linux.orig/drivers/md/dm-stripe.c
+++ linux/drivers/md/dm-stripe.c
@@ -132,7 +132,6 @@ static int stripe_ctr(struct dm_target *
 		return -EINVAL;
 	}
 
-	width = ti->len;
 	if (sector_div(width, stripes)) {
 		ti->error = "Target length not divisible by "
 		    "number of stripes";
